@@ -44,15 +44,17 @@ sub handle_request {
 
     # TODO : move that elsewhere
     if (setting('auto_reload')) {
-        die "Module::Refresh is not installed, " . 
-            "install this module or unset 'auto_reload' in your config file" 
-            unless Dancer::ModuleLoader->load('Module::Refresh');
-
+        if (Dancer::ModuleLoader->load('Module::Refresh')) {
             my $orig_reg = Dancer::Route->registry;
             Dancer::Route->purge_all;
             Module::Refresh->refresh;
             my $new_reg = Dancer::Route->registry;
             Dancer::Route->merge_registry($orig_reg, $new_reg);
+        }
+        else {
+            warn "Module::Refresh is not installed, " . 
+                "install this module or unset 'auto_reload' in your config file";
+        }
     }
 
     my $response;
